@@ -31,7 +31,7 @@ import os
 from fnmatch import fnmatch
 import hashlib
 
-VERSION = "1.8.7"
+VERSION = "1.8.8"
 
 DEFAULT_CCN_THRESHOLD = 15
 
@@ -338,8 +338,8 @@ class CodeReader(object):
                 r"(?:\w+" +
                 r"|/\*.*?\*/" +
                 addition +
-                r"|\"(?:\\.|[^\"])*\"" +
-                r"|\'(?:\\.|[^\'])*?\'" +
+                r"|\"(?:\\.|[^\"\\])*\"" +
+                r"|\'(?:\\.|[^\'\\])*?\'" +
                 r"|//" + _until_end +
                 r"|\#" +
                 r"|:=|::|\*\*" +
@@ -351,7 +351,7 @@ class CodeReader(object):
             macro = ""
             for token in token_pattern.findall(source_code):
                 if macro:
-                    if token == "\\\n" or "\n" not in token:
+                    if "\\\n" in token or "\n" not in token:
                         macro += token
                     else:
                         yield macro
@@ -422,7 +422,9 @@ class CLikeReader(CodeReader, CCppCommentsMixin):
         self.bracket_stack = []
 
     def _state_global(self, token):
-        if token == 'typedef':
+        if token in ("class", "namespace"):
+            self._state = self._state_namespace_def
+        elif token == 'typedef':
             self._state = self._state_typedef
         elif token[0].isalpha() or token[0] == '_':
             self.context.start_new_function(token)
@@ -430,6 +432,10 @@ class CLikeReader(CodeReader, CCppCommentsMixin):
             if token == 'operator':
                 self._state = self._state_operator
 
+    def _state_namespace_def(self, token):
+        if token in '{;':
+            self._state = self._state_global
+
     def _state_typedef(self, token):
         if token == ';':
             self._state = self._state_global
@@ -454,7 +460,7 @@ class CLikeReader(CodeReader, CCppCommentsMixin):
             self.bracket_stack.append(token)
         elif token in (">", ">>"):
             for _ in token:
-                if self.bracket_stack.pop() != "<":
+                if not self.bracket_stack or self.bracket_stack.pop() != "<":
                     self._reset_to_global()
         if not self.bracket_stack:
             self._state = self._state_function
@@ -518,14 +524,20 @@ class CLikeReader(CodeReader, CCppCommentsMixin):
     def _state_old_c_params(self, token):
         self._saved_tokens.append(token)
         if token == ';':
+            self._saved_tokens = []
             self._state = self._state_dec_to_imp
         elif token == '{':
             if len(self._saved_tokens) == 2:
+                self._saved_tokens = []
                 self._state_dec_to_imp(token)
                 return
             self._state = self._state_global
             for token in self._saved_tokens:
                 self._state(token)
+        elif token == '(':
+            self._state = self._state_global
+            for token in self._saved_tokens:
+                self._state(token)
 
     def _state_initialization_list(self, token):
         if token == '{':
@@ -647,6 +659,7 @@ class FileAnalyzer(object):  # pylint: disable=R0903
                              % filename)
 
     def analyze_source_code(self, filename, code):
+        print(filename)
         context = CodeInfoContext(filename)
         reader = (CodeReader.get_reader(filename) or CLikeReader)(context)
         tokens = reader.generate_tokens(code)
